<?php



//    Add custom link input box to the Jumbtron Slides editor
add_action( 'edit_form_after_title', 'gijt_meta_box_add', 1  );
function gijt_meta_box_add() {
    
    add_meta_box(   'gijt-meta-box-id', 
                    'Custom Link for Slide', 
                    'gijt_meta_box_cb', 
                    'gi_jumboslides', 
                    'gijt_after_title', 
                    'default' );
}



function gijt_meta_box_cb( $post ) {
    
    $values = get_post_custom( $post->ID );
    
    global $selectedLink;
    
    $selectedLink = isset( $values['my_meta_box_linkChoice__text'] ) ? esc_attr( $values['my_meta_box_linkChoice__text'][0] ) : '';
    
    wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
    
    ?>
    <div class="gijt-mb-outerwrap">

        <div class="gijt-mb-innererwrap">
            
            <p> The default link will be the parent page, but you can add to that URL or input an entire URL. To only add to the existing, simply add everything specific to the desired page. For example, for a category called "Photos", simply put <code>/category/photos</code>.
            </p>
            <label for="my_meta_box_linkChoice_text"> Slide Link</label>
            
            <input type="text" name="my_meta_box_linkChoice__text" id="my_meta_box_linkChoice__text" size="100" value="<?php echo $selectedLink; ?>" />
            
            <br>
            
            <h4>Your Current Link Selection</h4>
            
            <h5><?php echo $selectedLink;?></h5>
         
        </div>   <!-- gijt-mb-innerwrap --> 
        
    </div> <!-- gijt-mb-outerwrap -->
    <?php
}



add_action( 'save_post', 'gijt_meta_box_save' );
function gijt_meta_box_save( $post_id ) {
    
    //    Bail if we're doing an auto save
    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
    //    if our nonce isn't there, or we can't verify it, bail
    if( !isset( $_POST['meta_box_nonce'] ) || !wp_verify_nonce( $_POST['meta_box_nonce'], 'my_meta_box_nonce' ) ) return;
    //    if our current user can't edit this post, bail
    if( !current_user_can( 'edit_post', $post_id ) ) return;
    //    now we can actually save the data
    $allowed = array( 
        'a' => array( // on allow a tags
            'href' => array() // and those anchords can only have href attribute
        )
    );
    //    Probably a good idea to make sure your data is set
    if( isset( $_POST['my_meta_box_linkChoice__text'] ) )
        update_post_meta( $post_id, 'my_meta_box_linkChoice__text', wp_kses( $_POST['my_meta_box_linkChoice__text'], $allowed ) );
}



//    *****************************
//      Turn the Jumbotron slide
//      title on or off.
//    ******************************
add_action( 'add_meta_boxes', 'gijt_mb_tt_add' );
function gijt_mb_tt_add() {
    
    add_meta_box(   'gijt-meta-box-tt', 
                    'Hide the Title On the Slide', 
                    'gijt_mb_title_toggle', 
                    'gi_jumboslides', 
                    'core', 
                    'high' );
}



function gijt_mb_title_toggle( $post ) {
    
    $values = get_post_custom( $post->ID );
    $titletoggle = 'no' ;
    wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
    ?>
    <p>
        <label>Check to hide the title</label>
        <?php $field_id_value = get_post_meta($post->ID, 'my_meta_box_title_toggle', true);
        
        if($field_id_value == "yes") {
            $field_id_checked = 'checked="checked"';
            $titletoggle = 'yes' ;
            }?>
        <input type="checkbox" name="my_meta_box_title_toggle" value="yes" <?php echo $field_id_checked; ?> />

        <p></p>
        <h4>Your Current Link Selection</h4>
         <h5><?php echo $titletoggle;?></h5>
    </p>
    <?php
}



add_action( 'save_post', 'gijt_mb_tt_save' );
function gijt_mb_tt_save( $post_id ) {
    
    //    Bail if we're doing an auto save
    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
    //    if our nonce isn't there, or we can't verify it, bail
    if( !isset( $_POST['meta_box_nonce'] ) || !wp_verify_nonce( $_POST['meta_box_nonce'], 'my_meta_box_nonce' ) ) return;
    //    if our current user can't edit this post, bail
    if( !current_user_can( 'edit_post', $post_id ) ) return;
    //    now we can actually save the data
    $allowed = array( 
        'a' => array( // on allow a tags
            'href' => array() // and those anchords can only have href attribute
        )
    );
        update_post_meta( $post_id, 'my_meta_box_title_toggle', wp_kses( $_POST['my_meta_box_title_toggle'], $allowed ) );
}



//     *****************************
//      Add custom css box 
//      for Jumbotron text
//     ******************************
add_action( 'edit_form_after_title', 'gijt_mb_hdcss_add' );
function gijt_mb_hdcss_add() {
    
    add_meta_box(   'gijt-meta-box-hdcss', 
                    'Add Css to the Title', 
                    'gijt_mb_hd_css', 
                    'gi_jumboslides', 
                    'advanced', 
                    'high' );
}



function gijt_mb_hd_css( $post ) {
    
    wp_nonce_field( 'my_meta_box_nonce', 'meta_box_nonce' );
    ?>
    
    <div class="metabox-css-wrap" style="display:flex; " >
        <div class="metabox-col-wrap" style="display:flex; flex-direction: column">
                
            <label>Title CSS</label>
            
            <?php $hd_css_value = get_post_meta($post->ID, 'my_meta_box_hd_css', true);
            ?>
    
            <textarea  cols="40" rows="5" name="my_meta_box_hd_css" ><?php echo $hd_css_value; ?></textarea>

        </div> <!-- END .metabox-css-wrap -->
        
        <div class="metabox-col-wrap" style="display:flex; flex-direction: column" >
            
            <label>Body CSS</label>
            
            <?php $txt_css_value = get_post_meta($post->ID, 'my_meta_box_txt_css', true);
            ?>
    
            <textarea  cols="40" rows="5" name="my_meta_box_txt_css" ><?php echo $txt_css_value; ?></textarea>
            
        </div> <!-- END .metabox-css-wrap -->
        
    </div> <!-- END .metabox-css-wrap -->
    
    <?php
}



add_action( 'save_post', 'gijt_mb_hdcss_save' );
function gijt_mb_hdcss_save( $post_id ) {
    
    //    Bail if we're doing an auto save
    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return;
    
    //    if our nonce isn't there, or we can't verify it, bail
    if( !isset( $_POST['meta_box_nonce'] ) || !wp_verify_nonce( $_POST['meta_box_nonce'], 'my_meta_box_nonce' ) ) return;
    
    //    if our current user can't edit this post, bail
    if( !current_user_can( 'edit_post', $post_id ) ) return;
    
    // now we can actually save the data
    $allowed = array(
        
        'a' => array( // on allow a tags
        
            'href' => array() // and those anchors can only have href attribute
        )
    );
    
        update_post_meta( $post_id, 'my_meta_box_hd_css', wp_kses( $_POST['my_meta_box_hd_css'], $allowed ) );
                
        update_post_meta( $post_id, 'my_meta_box_txt_css', wp_kses( $_POST['my_meta_box_txt_css'], $allowed ) );
}


add_action( 'admin_head', 'gijt_mb_css' );
function gijt_mb_css( $post_id ) {
    
    echo '<style>

            .post-type-gi_jumboslides h1.wp-heading-inline {
                padding: 1em 1em 1em 3em;
                width: 100%;
                font-size: 34px;
                font-weight: 700;
            }
            
            .post-type-gi_jumboslides .wp-heading-inline, .post-type-gi_jumboslides #gijt-meta-box-id, .post-type-gi_jumboslides #gijt-meta-box-tt, .post-type-gi_jumboslides #gijt-meta-box-hdcss, .post-type-gi_jumboslides #pageparentdiv, .post-type-gi_jumboslides #postimagediv {
                font-variant: all-small-caps;
                font-size: 18px;
                letter-spacing: .2em;
                text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.5), 0 1px 0 rgba(255, 255, 255, .25);
                color: #f6f6f6;
                border: 1px solid white;
                border-right: none;
                border-bottom: none;
                background: rgb(177, 177, 177);
                background: -moz-linear-gradient(top, rgb(177, 177, 177) 0%,rgb(99, 99, 99) 100%);
                background: -webkit-linear-gradient(top, rgb(177, 177, 177) 0%,rgb(99, 99, 99) 100%);
                background: linear-gradient(to bottom, rgb(177, 177, 177) 0%,rgb(99, 99, 99) 100%);
                box-shadow: 5px 6px 4px -4px rgb(0, 0, 0);
            }
            
            .post-type-gi_jumboslides #gijt-meta-box-id, .post-type-gi_jumboslides #gijt-meta-box-tt, .post-type-gi_jumboslides #gijt-meta-box-hdcss, .post-type-gi_jumboslides #pageparentdiv, .post-type-gi_jumboslides #postimagediv {
                padding: 2em;
            }
            
            .post-type-gi_jumboslides #remove-post-thumbnail, .post-type-gi_jumboslides #set-post-thumbnail-desc {
                color: hsla(199, 100%, 112%, 1);
            }

            .post-type-gi_jumboslides  .gijt-mb-innererwrap p {
                font-variant: none;
                font-size: 18px;
                letter-spacing: .1em;
            }
            
            .post-type-gi_jumboslides .page-title-action {
                background: hsla(14, 100%, 26%, 1) !important;
                color: white !important;
                border-radius: 10px !important;
                border: 1px outset rgba(255, 255, 255, 0.3686274509803922) !important;
                padding: .5em 1em!important;
            }
            .post-type-gi_jumboslides #sharing_meta, .post-type-gi_jumboslides #formatdiv {
                display: none !important;
            }
            
         </style>
         
         '; 
}

?>